<?php

$results = array(
	'active'   => array(),
	'inactive' => array(),
	'disabled' => array(),
);

$summary = array(
	'active'   => 0,
	'inactive' => 0,
	'disabled' => 0,
	'usable'   => 0,
);

$disabled = apply_filters( 'sct_disable_reset_tools_' . $scope, $settings['disabled'][ $scope ] );

foreach ( smart_sct_core()->cleanup as $code => $data ) {
	if ( ! in_array( $code, $disabled ) ) {
		$summary['usable'] ++;

		$class_name = $data['class'];
		$clean      = new $class_name( $scope, $code );
		$check      = $clean->check();
		$help       = $clean->help();

		$render = '<div class="sct-cleanup-box' . ( $check['records'] == 0 ? ' sct-disabled' : '' ) . ( $check['checked'] ? ' sct-enabled' : '' ) . '">';
		$render .= '<h3 class="sct-cleanup-title">' . $data['label'] . '</h3>';
		$render .= '<div class="sct-cleanup-statusbox">';
		$render .= $check['display'];
		$render .= '</div>';
		$render .= '<div class="sct-cleanup-infobox">';
		$render .= $clean->form();
		$render .= '</div>';
		$render .= '<div class="sct-cleanup-checkbox">';
		if ( $check['records'] == 0 ) {
			$render .= esc_html__( 'No action required', 'smart-cleanup-tools' );
		} else {
			$render .= $clean->draw_checkbox( $check['checked'] );

			if ( ! empty( $help ) ) {
				$render .= '<a class="sct-tool-help sct-state-active" title="' . esc_html__( 'More information available for this tweak.', 'smart-cleanup-tools' ) . '" href="#' . $code . '"><span class="dashicons dashicons-info"></span></a>';
			}
		}
		$render .= '</div>';

		if ( ! empty( $help ) ) {
			$render .= '<div title="' . esc_html__( 'Help', 'smart-cleanup-tools' ) . ': ' . $data['label'] . '" id="sct-help-' . $code . '" style="display: none;">';
			$render .= $help;
			$render .= '</div>';
		}
		$render .= '</div>';

		if ( $check['records'] == 0 ) {
			if ( $settings['cleanup_show_inactive'] ) {
				$results['inactive'][] = $render;
			}

			$summary['inactive'] ++;
		} else {
			$results['active'][] = $render;
			$summary['active'] ++;
		}
	} else {
		$results['disabled'][] = $code;
		$summary['disabled'] ++;
	}
}

?>
<form method="POST" id="sct-cleanup-form">
	<?php wp_nonce_field( "smart-cleanup-tools-cleanup" ); ?>

    <input type="hidden" name="sct[scope]" value="<?php echo esc_attr( $scope ); ?>"/>
    <input type="hidden" name="sct[quick]" value="off"/>

    <div class="spw-panel-two-columns">
        <div class="spw-column-left">
            <p>
				<?php esc_html_e( 'Select reset tools you want to use, and set up options if needed.', 'smart-cleanup-tools' ); ?>
            </p>

			<?php if ( $settings['cleanup_summary'] ) { ?>
                <div class="sct-cleanup-totals">
                    <table style="width: 100%;">
                        <tr>
                            <td style="text-align: left;"><?php esc_html_e( 'Active Tools', 'smart-cleanup-tools' ); ?></td>
                            <td style="text-align: right; font-weight: bold;"><?php echo esc_html( $summary['active'] ); ?></td>
                        </tr>
                    </table>
                    <table style="width: 100%; border-top: 1px dotted #333;">
                        <tr>
                            <td style="text-align: left;"><?php esc_html_e( 'Inactive Tools', 'smart-cleanup-tools' ); ?></td>
                            <td style="text-align: right; font-weight: bold;"><?php echo esc_html( $summary['inactive'] ); ?></td>
                        </tr>
                        <tr>
                            <td style="text-align: left;"><?php esc_html_e( 'Disabled Tools', 'smart-cleanup-tools' ); ?></td>
                            <td style="text-align: right; font-weight: bold;"><?php echo esc_html( $summary['disabled'] ); ?></td>
                        </tr>
                    </table>
                </div>
			<?php } ?>
            <input id="sct-cleanup-run" class="button-primary" type="submit" value="<?php esc_attr_e( 'Run Reset', 'smart-cleanup-tools' ); ?>"/>
            <p class="sct-basic-info">
				<?php esc_html_e( 'These tools will reset some of data, and it is good idea to create backup if you decide to revert it back later.', 'smart-cleanup-tools' ); ?>
            </p>

            <p class="sct-left-info sct-top-notice">
				<?php esc_html_e( 'Time needed to complete cleanup process depends on the size of your database, number of cleanup operations selected and amount of data that will get removed during this process.', 'smart-cleanup-tools' ); ?>
            </p>
        </div>
        <div class="spw-column-right">
            <div class="sct-cleanup-box-wrapper">
				<?php

				echo join( '', $results['active'] );
				echo join( '', $results['inactive'] );

				if ( $summary['usable'] == 0 ) {
					echo '<h3 style="margin-top: 0; margin-left: 15px;">' . esc_html__( 'All available reset tools are disabled.', 'smart-cleanup-tools' ) . '</h3>';
				}

				?>
            </div>
        </div>
    </div>
</form>